==> ripe-dbase-3.0.tar.gz: ripe-dbase-3.0/modules/ca/ca_initFn.c <==
/***************************************
  $Revision:

  CA module: a wrapper for the functions which parse the
             dictionary, configuration and source files.

  Status: NOT REVIEWED, NOT TESTED

  Author(s):       Ambrose Magee

******************//******************
Modification History:

******************/

/************************************
Copyright (c) 2000                              RIPE NCC

All Rights Reserved

Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation, and that the name of the author not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS; IN NO EVENT SHALL
AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
***************************************/

#include <stdio.h>
#include <string.h>
#include "ca_defs.h"
#include "ca_configFns.h"
#include "ca_dictionary.h"

/* #define DEBUG */

/*
 * The initialization function.
 */

void ca_init(const char *configFile)
/****************************************************************
 * ca_init() -- Initialisation function;                *
  *          - a wrapper for the ca_populateDictionary,`    *
  *            the ca_readConfig and the ca_readSources    *
 *            functions.                        *
 *                                          *
 * Parameters                                  *
  *      configFile -- the name of the configuration file    *
 *                                          *
 * Returns                                    *
  *    Nothing -- perhaps make this return 0 on successful     *
 *            completion ?                        *
 *                                          *
 ****************************************************************/
{
	/*
	 * We use CA_NUMBEROFSYMBOLS instead.
	 * int varNo = VARS;
	 */

int varNo = CA_NUMBEROFSYMBOLS;

	/*
	 * We do not need this function now; the dictionary is hardcoded.
	 *
	 * ca_populateDictionary(dictionary, varNo);
  */	

 #ifdef DEBUG
 ca_getDictionary(dictionary, varNo);
	#endif /* DEBUG */

	ca_readConfig(configFile, confVars, varNo);
 /*
	 * ca_sanityChk(confVars);
	 */
if (ca_mandVarChk() != 0)
		{
		fprintf(stderr, "Mandatory variable(s) undefined\n\n");
		fprintf(stderr, "<<<<<<<<<<<<<<<     >>>>>>>>>>>\n\n");
		}

	/*
	 * sourcesFile = ca_get_dirlist(94);
	 */
	sourcesFile = ca_get_dirlist(CA_SOURCEFILE);
	ca_readSources(sourcesFile, confVars);
}

==> ripe-dbase-3.0.1.tar.gz: ripe-dbase-3.0.1/modules/ca/ca_initFn.c <==
/***************************************
  $Revision:

  CA module: a wrapper for the functions which parse the
             dictionary, configuration and source files.

  Status: NOT REVIEWED, NOT TESTED

  Author(s):       Ambrose Magee

******************//******************
Modification History:

******************/

/************************************
Copyright (c) 2000                              RIPE NCC

All Rights Reserved

Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation, and that the name of the author not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS; IN NO EVENT SHALL
AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
***************************************/

#include <stdio.h>
#include <string.h>
#include "ca_defs.h"
#include "ca_configFns.h"
#include "ca_dictionary.h"

/* #define DEBUG */

/*
 * The initialization function.
 */

int ca_init(const char *configFile)
/****************************************************************
 * ca_init() -- Initialisation function;                *
  *          - a wrapper for the ca_populateDictionary,`    *
  *            the ca_readConfig and the ca_readSources    *
 *            functions.                        *
 *                                          *
 * Parameters                                  *
  *      configFile -- the name of the configuration file    *
 *                                          *
 * Returns                                    *
  *    An integer; the return value of ca_mandVarChk().
 *                                          *
 ****************************************************************/
{
	/*
	 * We use CA_NUMBEROFSYMBOLS instead.
	 * int varNo = VARS;
	 */

int varNo = CA_NUMBEROFSYMBOLS;

	/*
	 * We do not need this function now; the dictionary is hardcoded.
	 *
	 * ca_populateDictionary(dictionary, varNo);
  */	

 #ifdef DEBUG
 ca_getDictionary(dictionary, varNo);
	#endif /* DEBUG */

	ca_readConfig(configFile, confVars, varNo);
 /*
	 * ca_sanityChk(confVars);
	 */
if (ca_mandVarChk() != 0)
		{
		fprintf(stderr, "Mandatory variable(s) undefined\n\n");
		fprintf(stderr, "<<<<<<<<<<<<<<<     >>>>>>>>>>>\n\n");
		fprintf(stderr, "Continuing ..... \n\n");

		}
	/*
	 * sourcesFile = ca_get_dirlist(94);
	 */
		sourcesFile = ca_get_dirlist(CA_SOURCEFILE);
		ca_readSources(sourcesFile, confVars);
		return(ca_mandVarChk());
}
